==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControllerConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ControllerConfigBuilder extends ControllerConfigFluentImpl<ControllerConfigBuilder> implements VisitableBuilder<ControllerConfig,ControllerConfigBuilder>{
  public ControllerConfigBuilder() {
    this(false);
  }
  public ControllerConfigBuilder(Boolean validationEnabled) {
    this(new ControllerConfig(), validationEnabled);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ControllerConfig(), validationEnabled);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,ControllerConfig instance) {
    this(fluent, instance, false);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,ControllerConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withClientBurst(instance.getClientBurst());
      fluent.withClientQPS(instance.getClientQPS());
      fluent.withConcurrentReconciles(instance.getConcurrentReconciles());
      fluent.withQueueBurst(instance.getQueueBurst());
      fluent.withQueueQPS(instance.getQueueQPS());
      fluent.withReplicas(instance.getReplicas());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ControllerConfigBuilder(ControllerConfig instance) {
    this(instance,false);
  }
  public ControllerConfigBuilder(ControllerConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withClientBurst(instance.getClientBurst());
      this.withClientQPS(instance.getClientQPS());
      this.withConcurrentReconciles(instance.getConcurrentReconciles());
      this.withQueueBurst(instance.getQueueBurst());
      this.withQueueQPS(instance.getQueueQPS());
      this.withReplicas(instance.getReplicas());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ControllerConfigFluent<?> fluent;
  Boolean validationEnabled;
  public ControllerConfig build() {
    ControllerConfig buildable = new ControllerConfig(fluent.getClientBurst(),fluent.getClientQPS(),fluent.getConcurrentReconciles(),fluent.getQueueBurst(),fluent.getQueueQPS(),fluent.getReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControllerConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ControllerConfigBuilder extends ControllerConfigFluent<ControllerConfigBuilder> implements VisitableBuilder<ControllerConfig,ControllerConfigBuilder>{
  public ControllerConfigBuilder() {
    this(false);
  }
  public ControllerConfigBuilder(Boolean validationEnabled) {
    this(new ControllerConfig(), validationEnabled);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ControllerConfig(), validationEnabled);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,ControllerConfig instance) {
    this(fluent, instance, false);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,ControllerConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ControllerConfig());

    if (instance != null) {
      fluent.withClientBurst(instance.getClientBurst());
      fluent.withClientQPS(instance.getClientQPS());
      fluent.withConcurrentReconciles(instance.getConcurrentReconciles());
      fluent.withQueueBurst(instance.getQueueBurst());
      fluent.withQueueQPS(instance.getQueueQPS());
      fluent.withReplicas(instance.getReplicas());
      fluent.withClientBurst(instance.getClientBurst());
      fluent.withClientQPS(instance.getClientQPS());
      fluent.withConcurrentReconciles(instance.getConcurrentReconciles());
      fluent.withQueueBurst(instance.getQueueBurst());
      fluent.withQueueQPS(instance.getQueueQPS());
      fluent.withReplicas(instance.getReplicas());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ControllerConfigBuilder(ControllerConfig instance) {
    this(instance,false);
  }
  public ControllerConfigBuilder(ControllerConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ControllerConfig());

    if (instance != null) {
      this.withClientBurst(instance.getClientBurst());
      this.withClientQPS(instance.getClientQPS());
      this.withConcurrentReconciles(instance.getConcurrentReconciles());
      this.withQueueBurst(instance.getQueueBurst());
      this.withQueueQPS(instance.getQueueQPS());
      this.withReplicas(instance.getReplicas());
      this.withClientBurst(instance.getClientBurst());
      this.withClientQPS(instance.getClientQPS());
      this.withConcurrentReconciles(instance.getConcurrentReconciles());
      this.withQueueBurst(instance.getQueueBurst());
      this.withQueueQPS(instance.getQueueQPS());
      this.withReplicas(instance.getReplicas());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ControllerConfigFluent<?> fluent;
  Boolean validationEnabled;
  public ControllerConfig build() {
    ControllerConfig buildable = new ControllerConfig(fluent.getClientBurst(),fluent.getClientQPS(),fluent.getConcurrentReconciles(),fluent.getQueueBurst(),fluent.getQueueQPS(),fluent.getReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
